Uncertainty Toolbox Documentation
=================================

**Uncertainty Toolbox** is a python toolbox for predictive uncertainty quantification,
calibration, metrics, and visualization.

|github| The code for Uncertainty Toolbox is `on github
<https://github.com/uncertainty-toolbox/uncertainty-toolbox>`_.

|homepage| Return to the website `homepage <https://uncertainty-toolbox.github.io/>`_.

.. |github| image:: assets/github.svg
  :width: 23
  :alt: github

.. |homepage| image:: assets/homepage.svg
  :width: 23
  :alt: homepage


User Guide
**********
.. toctree::
  :maxdepth: 2

  installation
  quick_start
  api_reference/index
